import { useState } from 'react';
import { FaExpand } from 'react-icons/fa';

export default function CustomYouTubePlayer({ videoId }: { videoId: string }) {
  const [isFullscreen, setIsFullscreen] = useState(false);

  const videoEmbedUrl = `https://www.youtube.com/embed/${videoId}?rel=0&modestbranding=1&iv_load_policy=3&controls=0&autoplay=1`;

  const toggleFullscreen = () => {
    const iframe = document.getElementById('youtube-player') as any; // Cast to `any` to avoid TypeScript issues
    const doc = document as any; // Cast to `any` to handle fullscreen exit

    if (!isFullscreen) {
      if (iframe?.requestFullscreen) {
        iframe.requestFullscreen();
      } else if (iframe?.mozRequestFullScreen) {
        iframe.mozRequestFullScreen(); // Firefox
      } else if (iframe?.webkitRequestFullscreen) {
        iframe.webkitRequestFullscreen(); // Chrome, Safari, and Opera
      } else if (iframe?.msRequestFullscreen) {
        iframe.msRequestFullscreen(); // IE/Edge
      }
      setIsFullscreen(true);
    } else {
      if (doc.exitFullscreen) {
        doc.exitFullscreen();
      } else if (doc.mozCancelFullScreen) {
        doc.mozCancelFullScreen(); // Firefox
      } else if (doc.webkitExitFullscreen) {
        doc.webkitExitFullscreen(); // Chrome, Safari, and Opera
      } else if (doc.msExitFullscreen) {
        doc.msExitFullscreen(); // IE/Edge
      }
      setIsFullscreen(false);
    }
  };

  return (
    <div className="relative w-full h-[30vh] md:h-[60vh]">
      {/* YouTube Iframe */}
      <iframe
        id="youtube-player"
        className="w-full h-full"
        src={videoEmbedUrl}
        allowFullScreen
        frameBorder="0"
      ></iframe>

      {/* Bottom Right Controls */}
      <div className="absolute bottom-4 right-4 flex space-x-3 text-white text-xl md:text-2xl">
        <button onClick={toggleFullscreen}>
          <FaExpand />
        </button>
      </div>
    </div>
  );
}
